.. _resources:

Other resources and learning material
#####################################

Vyper has an active community. You can find third-party tutorials, examples, courses, and other learning material.

General
-------

- `Ape Academy – Learn how to build Vyper projects <https://academy.apeworx.io/>`_ by ApeWorX
- `More Vyper by Example <https://vyper-by-example.org/>`_ by Smart Contract Engineer
- `Vyper cheat Sheet <https://reference.auditless.com/cheatsheet>`_
- `Vyper Hub for development <https://github.com/zcor/vyper-dev>`_
- `Vyper greatest hits smart contract examples <https://github.com/pynchmeister/vyper-greatest-hits/tree/main/contracts>`_
- `A curated list of Vyper resources, libraries, tools, and more <https://github.com/stars/pcaversaccio/lists/vyper>`_

Frameworks and tooling
----------------------

- `Titanoboa – An experimental Vyper interpreter with pretty tracebacks, forking, debugging features and more <https://github.com/vyperlang/titanoboa/>`_
- `ApeWorX – The Ethereum development framework for Python Developers, Data Scientists, and Security Professionals <https://www.apeworx.io/>`_
- `VyperDeployer – A helper smart contract to compile and test Vyper contracts in Foundry <https://github.com/pcaversaccio/snekmate/blob/main/lib/utils/VyperDeployer.sol>`_
- `🐍 snekmate – Vyper smart contract building blocks <https://github.com/pcaversaccio/snekmate>`_
- `Serpentor – A set of smart contracts tools for governance <https://github.com/yearn/serpentor>`_
- `Smart contract development frameworks and tools for Vyper on Ethereum.org <https://ethereum.org/en/developers/docs/programming-languages/python/>`_
- `Vyper Online Compiler - an online platform for compiling and deploying Vyper smart contracts <https://github.com/0x0077/vyper-online-compiler>`_

Security
--------

- `VyperPunk – learn to secure and hack Vyper smart contracts <https://github.com/SupremacyTeam/VyperPunk>`_
- `VyperExamples – Vyper vulnerability examples <https://www.vyperexamples.com/reentrancy>`_

Conference presentations
------------------------

- `Vyper Smart Contract Programming Language by Patrick Collins (2022, 30 mins) <https://www.youtube.com/watch?v=b-sOMNF9quo&t=1444s>`_
- `Python and DeFi by Curve Finance (2022, 15 mins) <https://www.youtube.com/watch?v=4HOU3z0LoDg>`_
- `My experience with Vyper over the years by Benjamin Scherrey (2022, 15 mins) <https://www.youtube.com/watch?v=_j7qF_GlyWE>`_
- `Short introduction to Vyper by Edison Que (3 mins) <https://www.youtube.com/watch?v=dXqln-keyHw&t=4s>`_

Unmaintained
------------

These resources have not been updated for a while, but may still offer interesting content.

- `Awesome Vyper curated resources <https://github.com/spadebuilders/awesome-vyper>`_
- `Brownie – Python framework for developing smart contracts (deprecated) <https://eth-brownie.readthedocs.io/en/stable/>`_
- `Foundry x Vyper – Foundry template to compile Vyper contracts <https://github.com/0xKitsune/Foundry-Vyper>`_
